==> owlapi-distribution-4.5.6-sources.jar: org/semanticweb/owlapi/reasoner/impl/OWLDataPropertyNodeSet.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.reasoner.impl;

import java.util.Set;

import javax.annotation.Nonnull;

import org.semanticweb.owlapi.model.OWLDataProperty;
import org.semanticweb.owlapi.reasoner.Node;

/**
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 * @since 3.0.0
 */
public class OWLDataPropertyNodeSet extends DefaultNodeSet<OWLDataProperty> {

    /** default constructor. */
    public OWLDataPropertyNodeSet() {}

    /**
     * @param entity
     *        the entity to be contained
     */
    public OWLDataPropertyNodeSet(@Nonnull OWLDataProperty entity) {
        super(entity);
    }

    /**
     * @param owlDataPropertyNode
     *        the node to be contained
     */
    public OWLDataPropertyNodeSet(
            @Nonnull Node<OWLDataProperty> owlDataPropertyNode) {
        super(owlDataPropertyNode);
    }

    /**
     * @param nodes
     *        the nodes to be contained
     */
    public OWLDataPropertyNodeSet(@Nonnull Set<Node<OWLDataProperty>> nodes) {
        super(nodes);
    }

    @Nonnull
    @Override
    protected DefaultNode<OWLDataProperty> getNode(OWLDataProperty entity) {
        return NodeFactory.getOWLDataPropertyNode(entity);
    }

    @Override
    protected DefaultNode<OWLDataProperty>
            getNode(Set<OWLDataProperty> entities) {
        return NodeFactory.getOWLDataPropertyNode(entities);
    }
}

==> owlapi-distribution-5.0.5-sources.jar: org/semanticweb/owlapi/reasoner/impl/OWLDataPropertyNodeSet.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.reasoner.impl;

import java.util.Set;
import java.util.stream.Stream;

import org.semanticweb.owlapi.model.OWLDataProperty;
import org.semanticweb.owlapi.reasoner.Node;

/**
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 * @since 3.0.0
 */
public class OWLDataPropertyNodeSet extends DefaultNodeSet<OWLDataProperty> {

    /** Default constructor. */
    public OWLDataPropertyNodeSet() {
        super();
    }

    /**
     * @param entity
     *        the entity to be contained
     */
    public OWLDataPropertyNodeSet(OWLDataProperty entity) {
        super(entity);
    }

    /**
     * @param owlDataPropertyNode
     *        the node to be contained
     */
    public OWLDataPropertyNodeSet(Node<OWLDataProperty> owlDataPropertyNode) {
        super(owlDataPropertyNode);
    }

    /**
     * @param nodes
     *        the nodes to be contained
     */
    public OWLDataPropertyNodeSet(Set<Node<OWLDataProperty>> nodes) {
        super(nodes);
    }

    /**
     * @param nodes
     *        the nodes to be contained
     */
    public OWLDataPropertyNodeSet(Stream<Node<OWLDataProperty>> nodes) {
        super(nodes);
    }

    @Override
    protected DefaultNode<OWLDataProperty> getNode(OWLDataProperty entity) {
        return NodeFactory.getOWLDataPropertyNode(entity);
    }

    @Override
    protected DefaultNode<OWLDataProperty> getNode(Set<OWLDataProperty> entities) {
        return NodeFactory.getOWLDataPropertyNode(entities);
    }
}
